@@ -19,6 +19,8 @@
 #' @param conf.level The level of confidence to be used in the confidence
 #' interval. Values from 0 to 1 and -1 to 0 are acceptable.
 #' @param plot If \code{TRUE}, plots density plot.
+#' @param bars plot on density plot bars for discrete values of lambda.
+#' @param ... Additional arguments send to \code{plot} function.
 #' @return A data frame with one row containing bounds of the confidence
 #' intervals and a name of the method used to calculate them.
 #' @note The browser-based graphical user interface for this function is
@@ -36,9 +38,9 @@
 #' # confidence interval
 #' par(mfrow = c(1,2))
 #' dpcr_density(k = 25, n = 55, average = TRUE, methods = "wilson", 
-#' 	     conf.level = 0.9)
+#' 	     conf.level = 0.95)
 #' dpcr_density(k = 25, n = 55, average = TRUE, methods = "wilson", 
-#' 	     conf.level = -0.9)
+#' 	     conf.level = -0.95)
 #' 
 #' # By setting average to FALSE the total number of positive molecules is 
 #' # calculated
@@ -102,7 +104,8 @@
 #' 
 #' @export dpcr_density
 dpcr_density <- function(k, n, average = FALSE, methods = "wilson", 
-                         conf.level = 0.95, plot = TRUE) {
+                         conf.level = 0.95, plot = TRUE, 
+                         bars = FALSE, ...) {
   dat <- dpcr_calculator(k, n, average)
   conf <- binom.confint(k, n, methods = methods, conf.level = conf.level)
   if (average) {
@@ -118,7 +121,7 @@ dpcr_density <- function(k, n, average = FALSE, methods = "wilson",
   names(conf)[2] <- "k"
   if (plot) {
     plot_distr(dat, ylab = "Density", xlab = xlab,
-               main = main)
+               main = main, bars = bars, ...)
     plot_conf_int(conf[1, 4:6], dat, "left", conf_int_col = adjustcolor("cyan4", 
                                                                         alpha.f = 0.15), 
                   conf_int_border = adjustcolor("cyan4", alpha.f = 0.15))
